''' https://en.wikipedia.org/wiki/International_System_of_Units MASS: https://en.wikipedia.org/wiki/Mass https://en.wikipedia.org/wiki/Scientific_notation https://en.wikipedia.org/wiki/Avogadro_constant QUANTIZATIONS: GRAMS: 1E+6 GRAMS MEGAGRAMS Mg 1E+3 GRAMS KILOGRAMS kg 1E+0 GRAMS GRAMS g 1E-3 GRAMS MILLIGRAMS mg 1 * (10^-3) GRAMS .0001 GRAMS 1E-6 GRAMS MICROGRAMS μg 1E-9 GRAMS NANOGRAMS ng IU: # # 1 IU Vitamin A = 0.3 μg retinol (~0.1 nmol) # = 0.6 μg beta-carotene # 1 IU VITAMIN A = 0.30E-6 GRAMS RETINOL = 0.60E-6 GRAMS BETA-CAROTENE EXAMPLES: MASS: [ "3.00", "mcg" ], MASS_ENOTE: [ "3.00E-6", "GRAMS" ] MASS: [ "92.30", "g" ] MASS_ENOTE: [ "3.00E-6", "GRAMS" ] FORMATS: E NOTATION: CARBOHYDRATES 92.30 GRAMS POTASSIUM 309.56E-3 GRAMS IRON, FE 3.55E-3 GRAMS VANADIUM 26.00E-6 GRAMS SILICA 3.00E-6 GRAMS ABBREVIATED PREFIX: https://en.wikipedia.org/wiki/Metric_prefix CARBOHYDRATES 92.30 g POTASSIUM 309.56 mg IRON, FE 3.55 mg VANADIUM 26.00 mcg SILICA 3.00 mcg CARBOHYDRATES 92.30000000 GRAMS POTASSIUM 0.30956000 GRAMS IRON, FE 0.00355000 GRAMS VANADIUM 0.00002600 GRAMS SILICA 0.00000300 GRAMS CARBOHYDRATES 92.300,000,00 GRAMS POTASSIUM 0.309,560,00 GRAMS IRON, FE 0.003,550,00 GRAMS VANADIUM 0.000,026,00 GRAMS SILICA 0.000,003,00 GRAMS CARBOHYDRATES 92.30 GRAMS POTASSIUM 309.56 E-3 GRAMS IRON, FE 3.55 E-3 GRAMS VANADIUM 26.00 E-6 GRAMS SILICA 3.00 E-6 GRAMS CARBOHYDRATES 92.30 GRAMS POTASSIUM 309.56 (10^-3) GRAMS IRON, FE 3.55 (10^-3) GRAMS VANADIUM 26.00 (10^-6) GRAMS SILICA 3.00 (10^-6) GRAMS PROTEIN 1.32 KILOGRAMS CARBOHYDRATES 92.30 GRAMS POTASSIUM 309.56 MILLIGRAMS IRON, FE 3.55 MILLIGRAMS VANADIUM 26.00 MICROGRAMS SILICA 3.00 MICROGRAMS '''